@@ -1,37 +1,60 @@
 """
 This modules is a wrapper around nbconvert
-It provides a cleaner version of the HTML content that can be embedded into existing HTML pages.
+It provides a cleaner version of the HTML content that can be embedded into
+existing HTML pages without breaking existing styles.
 """
 
 import io
+import json
 import logging
 import os
-from copy import deepcopy
 
 import jupytext
+import mistune
 from nbconvert.exporters import HTMLExporter, MarkdownExporter
 from nbconvert.filters.highlight import _pygments_highlight
+from nbconvert.filters.markdown_mistune import (
+    IPythonRenderer,
+    MarkdownWithMath,
+)
 from nbconvert.nbconvertapp import NbConvertApp
-from nbconvert.preprocessors import Preprocessor
+from pygments import highlight
 from pygments.formatters import HtmlFormatter
-from traitlets import Integer
+from pygments.lexers import get_lexer_by_name
+from pygments.util import ClassNotFound
 
+from mkdocs_jupyter.config import settings
+from mkdocs_jupyter.preprocessors import SubCell
 
-# Variables
 logger = logging.getLogger("mkdocs.mkdocs-jupyter")
 
-# END variables
-
-
-THIS_DIR = os.path.dirname(os.path.realpath(__file__))
+# Language of the kernel (used for syntax highlighting)
+kernel_lang = "python"
 
+# We use this to tag each div with code with an unique ID for the copy-to-clipboard
 cell_id = 0
 
 
 def nb2html(
-    nb_path, start=0, end=None, execute=False, kernel_name="", theme=None
+    nb_path, execute=False, kernel_name="", theme=None, start=0, end=None
 ):
-    """Convert a notebook
+    """
+    Convert a notebook to HTML
+
+    Arguments
+    ---------
+        nb_path: str
+            Path to the notebook
+        execute: bool
+            Whether to execute the notebook
+        kernel_name: str
+            Name of the kernel to use
+        theme: str
+            Name of the theme to use (default: light) (options: light or dark)
+        start: int
+            Start cell number
+        end: int
+            End cell number
 
     Returns
     -------
@@ -39,16 +62,16 @@ def nb2html(
     """
     logger.info(f"Converting notebook (execute={execute}): {nb_path}")
 
-    global cell_id
-    cell_id = 0  # Reset this global value
+    global cell_id, kernel_lang
+    cell_id = 0  # Reset the cell id
 
     app = get_nbconvert_app(
-        start=start, end=end, execute=execute, kernel_name=kernel_name
+        execute=execute, kernel_name=kernel_name, start=start, end=end
     )
 
     # Use the templates included in this package
     template_file = "mkdocs_html/notebook.html.j2"
-    extra_template_paths = [os.path.join(THIS_DIR, "templates")]
+    extra_template_paths = [settings.templates_dir]
 
     # Customize NBConvert App
     preprocessors_ = [SubCell]
@@ -73,6 +96,9 @@ def nb2html(
         nb_file = io.StringIO(jupytext.writes(nb, fmt="ipynb"))
         content, resources = exporter.from_file(nb_file)
     else:
+        with open(nb_path, "r") as f:
+            nb_json = json.load(f)
+            kernel_lang = nb_json["metadata"]["kernelspec"]["language"]
         content, resources = exporter.from_filename(nb_path)
 
     return content
@@ -91,7 +117,7 @@ def nb2md(nb_path, start=0, end=None, execute=False, kernel_name=""):
 
     # Use the templates included in this package
     template_file = "mkdocs_md/md-no-codecell.md.j2"
-    extra_template_paths = [os.path.join(THIS_DIR, "templates")]
+    extra_template_paths = [settings.templates_dir]
 
     exporter = MarkdownExporter(
         config=app.config,
@@ -110,7 +136,11 @@ def nb2md(nb_path, start=0, end=None, execute=False, kernel_name=""):
     return body
 
 
-def get_nbconvert_app(start=0, end=None, execute=False, kernel_name=""):
+def get_nbconvert_app(
+    execute=False, kernel_name="", start=0, end=None
+) -> NbConvertApp:
+    """Create"""
+
     # Load the user's nbconvert configuration
     app = NbConvertApp()
     app.load_config_file()
@@ -136,43 +166,18 @@ def get_nbconvert_app(start=0, end=None, execute=False, kernel_name=""):
     return app
 
 
-class SliceIndex(Integer):
-    """An integer trait that accepts None
-    Used by the SubCell Preprocessor"""
-
-    default_value = None
-
-    def validate(self, obj, value):
-        if value is None:
-            return value
-        else:
-            return super(SliceIndex, self).validate(obj, value)
-
-
-class SubCell(Preprocessor):
-    """A preprocessor to select a slice of the cells of a notebook"""
-
-    start = SliceIndex(0, config=True, help="First cell of notebook")
-    end = SliceIndex(None, config=True, help="Last cell of notebook")
-
-    def preprocess(self, nb, resources):
-        nbc = deepcopy(nb)
-        nbc.cells = nbc.cells[self.start : self.end]
-        return nbc, resources
-
-
-def custom_highlight_code(source, language="python", metadata=None):
+def custom_highlight_code(source, language=None, metadata=None):
     """
-    Makes the CSS class of the div that contains the `<pre>`
-    be `.highlight-ipynb` instead of `.highlight`.
+    Change CSS class names from .highlight to .highlight-ipynb.
+    This are for the <div> that contains the <pre>
 
-    This modifies only HTML content not CSS
-    On the notebook.html.js we modify the CSS styles
+    This modifies only the HTML not CSS.
+    On the `notebook.html.js` template we modify the CSS styles.
     """
     global cell_id
     cell_id = cell_id + 1
     if not language:
-        language = "python"
+        language = kernel_lang
 
     formatter = HtmlFormatter(cssclass="highlight-ipynb hl-" + language)
     output = _pygments_highlight(source, formatter, language, metadata)
@@ -182,22 +187,13 @@ def custom_highlight_code(source, language="python", metadata=None):
     return output + clipboard_copy_txt
 
 
-# This sections creates a new markdown2html filter
-# This filter uses a Custom Rendered that uses a custom CodeHtmlFormatter
-# All this does is to wrap the language blocks into a div and a pre
-# So that it's the same that for regular non-language sections
-
-import mistune
-from pygments import highlight
-from pygments.util import ClassNotFound
-from pygments.lexers import get_lexer_by_name
-from nbconvert.filters.markdown_mistune import (
-    MarkdownWithMath,
-    IPythonRenderer,
-)
-
-
 def custom_markdown2html(source):
+    """
+    This filter uses a Custom Rendered that uses a custom CodeHtmlFormatter
+    to wrap the language blocks into a <div> and a <pre> tags.
+    This is done so it's the same HTML structure that for regular non-language
+    sections.
+    """
     return MarkdownWithMath(
         renderer=CustomMarkdownRendered(escape=False)
     ).render(source)
@@ -205,13 +201,13 @@ def custom_markdown2html(source):
 
 class CustomMarkdownRendered(IPythonRenderer):
     def block_code(self, code, lang):
+        lexer = None
         if lang:
             try:
                 lexer = get_lexer_by_name(lang, stripall=True)
             except ClassNotFound:
                 code = lang + "\n" + code
                 lang = None
-                lexer = None
 
         if not lang:
             return "\n<pre><code>%s</code></pre>\n" % mistune.escape(code)
